summaryrefslogtreecommitdiffstats
path: root/kdesktop/kdiconview.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kdesktop/kdiconview.cc')
-rw-r--r--kdesktop/kdiconview.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/kdesktop/kdiconview.cc b/kdesktop/kdiconview.cc
index 57287014a..ba772c39d 100644
--- a/kdesktop/kdiconview.cc
+++ b/kdesktop/kdiconview.cc
@@ -996,9 +996,9 @@ bool KDIconView::makeFriendlyText( KFileIVI *fileIVI )
{
KURL u( item->url() );
u.addPath( ".directory" );
// using KStandardDirs as this one checks for path being
// a file instead of a directory
- if ( KStandardDirs::exists( u.path() ) )
+ if ( TDEStandardDirs::exists( u.path() ) )
desktopFile = u.path();
}
else if ( isDesktopFile( item ) )
@@ -1029,7 +1029,7 @@ bool KDIconView::makeFriendlyText( KFileIVI *fileIVI )
}
if (cfg.hasKey("TryExec"))
{
- if (KStandardDirs::findExe( cfg.readEntry( "TryExec" ) ).isEmpty())
+ if (TDEStandardDirs::findExe( cfg.readEntry( "TryExec" ) ).isEmpty())
return false;
}
@@ -996,9 +996,9 @@ bool KDIconView::makeFriendlyText( KFileIVI *fileIVI )
KURL u( item->url() );
u.addPath( ".directory" );
- // using KStandardDirs as this one checks for path being
+ // using TDEStandardDirs as this one checks for path being
// a file instead of a directory